@@ -82,6 +82,14 @@ class Payment(ObjectBase):
     def amount_remaining(self):
         return self._get_property("amountRemaining")
 
+    @property
+    def amount_captured(self):
+        return self._get_property("amountCaptured")
+
+    @property
+    def amount_chargedback(self):
+        return self._get_property("amountChargedBack")
+
     @property
     def description(self):
         return self._get_property("description")
@@ -150,6 +158,10 @@ class Payment(ObjectBase):
     def details(self):
         return self._get_property("details")
 
+    @property
+    def routing(self):
+        return self._get_property("routing")
+
     # documented _links
 
     @property
@@ -227,6 +239,15 @@ class Payment(ObjectBase):
     def has_refunds(self):
         return self._get_link("refunds") is not None
 
+    def has_chargebacks(self):
+        return self._get_link("chargebacks") is not None
+
+    def has_captures(self):
+        return self._get_link("captures") is not None
+
+    def has_split_payments(self):
+        return self._get_property("routing") is not None
+
     def can_be_refunded(self):
         return self._get_property("amountRemaining") is not None
 
